Index: src/pdf/SkPDFCanon.h |
diff --git a/src/pdf/SkPDFCanon.h b/src/pdf/SkPDFCanon.h |
index 5198e7b0acb36452116e5d6ca69328fe5b62dcdf..2ad5a229aaa7923adf508f4f035bb295ffac4ca7 100644 |
--- a/src/pdf/SkPDFCanon.h |
+++ b/src/pdf/SkPDFCanon.h |
@@ -40,9 +40,9 @@ public: |
// reset to original setting, unrefs all objects. |
void reset(); |
// Returns exact match if there is one. If not, it returns NULL. |
// If there is no exact match, but there is a related font, we |
// still return NULL, but also set *relatedFont. |
SkPDFFont* findFont(uint32_t fontID, |
uint16_t glyphID, |
SkPDFFont** relatedFont) const; |
@@ -78,7 +78,7 @@ private: |
SkTDArray<SkPDFImageShader*> fImageShaderRecords; |
struct WrapGS { |
- explicit WrapGS(const SkPDFGraphicState* ptr = NULL) : fPtr(ptr) {} |
+ explicit WrapGS(const SkPDFGraphicState* ptr = nullptr) : fPtr(ptr) {} |
const SkPDFGraphicState* fPtr; |
bool operator==(const WrapGS& rhs) const { |
SkASSERT(fPtr); |
@@ -40,9 +40,9 @@ public: |
// reset to original setting, unrefs all objects. |
void reset(); |
- // Returns exact match if there is one. If not, it returns NULL. |
+ // Returns exact match if there is one. If not, it returns nullptr. |
// If there is no exact match, but there is a related font, we |
@@ -40,9 +40,9 @@ public: |
// If there is no exact match, but there is a related font, we |
- // still return NULL, but also set *relatedFont. |
+ // still return nullptr, but also set *relatedFont. |
SkPDFFont* findFont(uint32_t fontID, |
uint16_t glyphID, |